[Qa-jenkins-scm] [jenkins.debian.net] 02/03: reproducible archlinux: refactor

Holger Levsen holger at moszumanska.debian.org
Fri Dec 11 13:44:12 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit f1eb745cc2ea25833ebb8c069d97c429922c4337
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Dec 11 14:39:51 2015 +0100

    reproducible archlinux: refactor
---
 bin/reproducible_build_archlinux_pkg.sh | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/bin/reproducible_build_archlinux_pkg.sh b/bin/reproducible_build_archlinux_pkg.sh
index a15f7bf..64b5c3e 100755
--- a/bin/reproducible_build_archlinux_pkg.sh
+++ b/bin/reproducible_build_archlinux_pkg.sh
@@ -39,9 +39,8 @@ handle_remote_error() {
 	exit 0
 }
 
-choose_package() {
-	echo "$(date -u ) - about to choose a package to be build"
-	# every 2 days we check for new archlinux packages
+update_archlinux_repositories() {
+	# every 2 days we check for new archlinux packages in all tested repositories
 	touch -d "$(date -d '2 days ago' '+%Y-%m-%d') 00:00 UTC" $DUMMY
 	local SESSION="archlinux-scheduler-$RANDOM"
 	schroot --begin-session --session-name=$SESSION -c jenkins-reproducible-archlinux
@@ -56,6 +55,12 @@ choose_package() {
 	done
 	schroot --end-session -c $SESSION
 	rm $DUMMY > /dev/null
+}
+
+choose_package() {
+	echo "$(date -u ) - choosing package to be build."
+	update_archlinux_repositories
+	local REPO
 	local PKG
 	for REPO in $ARCHLINUX_REPOS ; do
 		case $REPO in

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list